@@ -101,7 +101,7 @@ static char *const *arg_next;
 static struct GNUNET_TIME_Relative delay;
 
 /**
- * Refenence to the delay task
+ * Reference to the delay task
  */
 static struct GNUNET_SCHEDULER_Task *delay_task;
 
@@ -259,13 +259,13 @@ shutdown_task (void *cls)
                    &qrDisplay.orig_vinfo))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                  "failed to reset originial display state\n");
+                  "failed to reset original display state\n");
     }
     /* close device */
-    close (qrDisplay.devicefd);
+    GNUNET_break (0 == close (qrDisplay.devicefd));
     qrDisplay.devicefd = -1;
     if (0 < qrDisplay.backlightfd)
-      close (qrDisplay.backlightfd);
+      GNUNET_break (0 == close (qrDisplay.backlightfd));
     qrDisplay.backlightfd = -1;
   }
 }
@@ -277,7 +277,7 @@ shutdown_task (void *cls)
  * @param cls closure
  * @param args arguments left
  * @param cfgfile config file name
- * @param cfg handle for the configuation file
+ * @param cfg handle for the configuration file
  */
 static void
 run (void *cls,
